## [0.1.0] - 2020-08-31
 
### Added
   
- first release
 
## [0.1.1] - 2020-09-23
 
### Added
- arxiv *.bib reference

### Changed
- variable names for better readability
- minor model modifications

### Fixed
- fix support for initial data points in [entmoot_minimize.py](https://github.com/cog-imperial/entmoot/blob/master/entmoot/optimizer/entmoot_minimize.py)

## [0.1.2] - 2020-11-03
 
### Added
- support for additional gurobi constraints
- additional scaling options for acquisition function

### Changed
- 

### Fixed
- fix passing of `acq_optimizer_kwargs`

## [0.1.4] - 2020-12-04 
 
### Added
- 

### Changed
- 

### Fixed
- fix installation process

## [0.2.0] - 2021-01-11
 
### Added
- support for categorical features
- uncertainty quantification for categorical features
- added testing for inputs and consistency

### Changed
- variable handling in optimization model, i.e. dictionaries for continuous and categorical variables
- default parameters values of LGBM model changed

### Fixed
- 

## [0.2.1] - 2021-01-18
 
### Added
- support for gurobi environments for integration with server license

### Changed
-

### Fixed
- 

## [0.2.2] - 2021-02-01
 
### Added
- allow consistent variable names for gurobi model and dimensions

### Changed
-

### Fixed
- 

## [0.2.3] - 2021-11-08
 
### Added
- add interface for BO library

### Changed
-

### Fixed
- 

## [1.0.0] - 2022-01-23
 
### Added
- support constraint multi-objective optimization for global optimizer
- complete interface for mbo

### Changed
- move model training and optimization from tell() to ask()

### Fixed
- input constraints fix

## [1.0.1] - 2022-11-23
 
### Added
-

### Changed
- remove rounding from x in Optimizer

### Fixed
- fixed test cases

## [1.0.2] - 2022-04-06
 
### Added
-

### Changed
-

### Fixed
- fix BO library interface

## [1.0.3] - 2022-04-21
 
### Added
-

### Changed
-

### Fixed
- remove 'fit' parameter in 'entmoot_optimize' to fix function

## [1.0.4] - 2022-06-29
 
### Added
-

### Changed
-

### Fixed
- update README examples for easier usage